@@ -1,7 +1,6 @@
 use crate::Error;
 
 pub use self::value::Value;
-
 pub mod value;
 
 mod message_channel;
@@ -28,6 +27,17 @@ pub struct MethodCallError<V> {
     pub details: V,
 }
 
+impl<T> std::fmt::Display for MethodCallError<T> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match &self.message {
+            Some(message) => {
+                write!(f, "{} ({})", message, self.code)
+            }
+            None => write!(f, "{}", self.code),
+        }
+    }
+}
+
 impl<V> MethodCallError<V> {
     pub fn from_code_message(code: &str, message: &str) -> Self
     where
