@@ -1,4 +1,9 @@
-use std::rc::{Rc, Weak};
+use std::{
+    cell::RefCell,
+    rc::{Rc, Weak},
+};
+
+use futures::Future;
 
 use crate::{util::LateRefCell, Error, Result};
 
@@ -7,7 +12,7 @@ use super::{
         app_delegate::ApplicationDelegateManager, drag_data::DragDataAdapter,
         engine::PlatformPlugin, init::init_platform,
     },
-    EngineManager, HotKeyManager, KeyboardMapManager, MenuManager, MessageManager,
+    EngineManager, HotKeyManager, JoinHandle, KeyboardMapManager, MenuManager, MessageManager,
     RegisteredMethodCallHandler, RunLoop, WindowManager, WindowMethodChannel,
 };
 
@@ -64,7 +69,7 @@ impl ContextImpl {
     fn initialize(&self, context: &ContextRef) -> Result<()> {
         init_platform().map_err(Error::from)?;
 
-        self.run_loop.set(RunLoop::new());
+        self.run_loop.set(RunLoop::new(context));
         self.engine_manager.set(EngineManager::new(context));
         self.message_manager.set(MessageManager::new(context));
         self.window_method_channel
@@ -117,6 +122,24 @@ impl Context {
     pub fn get(&self) -> Option<ContextRef> {
         self.context.upgrade().map(|c| ContextRef { context: c })
     }
+
+    pub fn current() -> Option<ContextRef> {
+        CURRENT_CONTEXT.with(|c| c.borrow().as_ref().and_then(|c| c.get()))
+    }
+}
+
+thread_local! {
+    static CURRENT_CONTEXT: RefCell<Option<Context>> = RefCell::new(None);
+}
+
+pub struct CurrentContextHandle {
+    previous: Option<Context>,
+}
+
+impl Drop for CurrentContextHandle {
+    fn drop(&mut self) {
+        CURRENT_CONTEXT.with(|c| *c.borrow_mut() = self.previous.take());
+    }
 }
 
 // Strong reference to a Context. Intentionally not clonable; There should be one
@@ -132,6 +155,23 @@ impl ContextRef {
             context: Rc::downgrade(&self.context),
         }
     }
+
+    // Sets the context as the current context for the current thread.
+    // The context is set as current while the result handle is in scope.
+    pub fn set_as_current(&self) -> CurrentContextHandle {
+        CurrentContextHandle {
+            previous: CURRENT_CONTEXT.with(|c| c.borrow_mut().replace(self.weak())),
+        }
+    }
+}
+
+// Spawn the future with current run loop as executor. This must be called on main
+// thread otherwise the method will panic (because there is no context associated
+// with current thread).
+pub fn spawn<T: 'static>(future: impl Future<Output = T> + 'static) -> JoinHandle<T> {
+    let context = Context::current().unwrap();
+    let run_loop = context.run_loop.borrow();
+    run_loop.spawn(future)
 }
 
 impl std::ops::Deref for ContextRef {
