@@ -1,4 +1,5 @@
 mod api_constants;
+mod async_method_call_handler;
 mod binary_messenger;
 mod bundle;
 mod context;
@@ -12,13 +13,14 @@ mod keyboard_map_manager;
 mod macros;
 mod menu_manager;
 mod message_manager;
-mod method_channel;
+mod method_call_handler;
 mod observatory;
 mod run_loop;
 mod window;
 mod window_manager;
 mod window_method_channel;
 
+pub use async_method_call_handler::*;
 pub use binary_messenger::*;
 pub use bundle::*;
 pub use context::*;
@@ -32,7 +34,7 @@ pub use keyboard_map_manager::*;
 pub use macros::*;
 pub use menu_manager::*;
 pub use message_manager::*;
-pub use method_channel::*;
+pub use method_call_handler::*;
 pub use observatory::*;
 pub use run_loop::*;
 pub use window::*;
