@@ -3,8 +3,10 @@ use std::fmt::Display;
 #[derive(Debug, Clone)]
 pub enum PlatformError {
     NotImplemented,
+    NotAvailable,
     UnknownError,
     GLibError { message: String },
+    OtherError { error: String },
 }
 
 pub type PlatformResult<T> = Result<T, PlatformError>;
@@ -15,12 +17,18 @@ impl Display for PlatformError {
             PlatformError::NotImplemented => {
                 write!(f, "Not Implemented")
             }
+            PlatformError::NotAvailable => {
+                write!(f, "Not Available")
+            }
             PlatformError::UnknownError => {
                 write!(f, "Unknown Error")
             }
             PlatformError::GLibError { message } => {
                 write!(f, "GLibError: {}", message)
             }
+            PlatformError::OtherError { error } => {
+                write!(f, "{}", error)
+            }
         }
     }
 }
