@@ -41,8 +41,6 @@ struct State {
     timer: Option<CFRunLoopTimer>,
 }
 
-unsafe impl Send for State {}
-
 struct StatePendingExecution {
     callbacks: Vec<Callback>,
     timers: Vec<Timer>,
@@ -134,15 +132,13 @@ impl State {
 
     extern "C" fn retain(data: *const c_void) -> *const c_void {
         let state = data as *const Mutex<State>;
-        let state = unsafe { Arc::from_raw(state) };
-        let _ = ManuallyDrop::new(state.clone()); // increase ref count
-        let _ = ManuallyDrop::new(state); // counter Arc::from_raw
+        unsafe { Arc::increment_strong_count(state) }
         data
     }
 
     extern "C" fn release(data: *const c_void) {
         let state = data as *const Mutex<State>;
-        unsafe { Arc::from_raw(state) }; // decrease ref count
+        unsafe { Arc::decrement_strong_count(state) };
     }
 
     extern "C" fn on_timer(_timer: CFRunLoopTimerRef, data: *mut c_void) {
@@ -172,6 +168,10 @@ pub struct PlatformRunLoop {
 
 impl PlatformRunLoop {
     pub fn new() -> Self {
+        unsafe {
+            let app = NSApplication::sharedApplication(nil);
+            NSApplication::setActivationPolicy_(app, NSApplicationActivationPolicyRegular);
+        }
         Self {
             next_handle: Cell::new(INVALID_HANDLE + 1),
             state: Arc::new(Mutex::new(State::new())),
@@ -220,7 +220,6 @@ impl PlatformRunLoop {
     pub fn run(&self) {
         unsafe {
             let app = NSApplication::sharedApplication(nil);
-            NSApplication::setActivationPolicy_(app, NSApplicationActivationPolicyRegular);
             NSApplication::activateIgnoringOtherApps_(app, YES);
             NSApplication::run(app);
         }
@@ -238,7 +237,7 @@ impl PlatformRunLoop {
                 location: NSPoint::new(0.0, 0.0)
                 modifierFlags: 0
                 timestamp: 0
-                    windowNumber: 0
+                windowNumber: 0
                 context: nil
                 subtype: 0
                 data1: 0
