@@ -11,7 +11,7 @@ use cocoa::{
     appkit::{
         CGPoint, NSApplication, NSEvent, NSEventType, NSScreen, NSView, NSViewHeightSizable,
         NSViewWidthSizable, NSWindow, NSWindowCollectionBehavior, NSWindowStyleMask,
-        NSWindowTabbingMode,
+        NSWindowTabbingMode, NSWindowTitleVisibility,
     },
     base::{id, nil, BOOL, NO, YES},
     foundation::{
@@ -397,8 +397,16 @@ impl PlatformWindow {
 
             if style.frame == WindowFrame::Regular {
                 NSWindow::setTitlebarAppearsTransparent_(*self.platform_window, NO);
+                NSWindow::setTitleVisibility_(
+                    *self.platform_window,
+                    NSWindowTitleVisibility::NSWindowTitleVisible,
+                );
             } else {
                 NSWindow::setTitlebarAppearsTransparent_(*self.platform_window, YES);
+                NSWindow::setTitleVisibility_(
+                    *self.platform_window,
+                    NSWindowTitleVisibility::NSWindowTitleHidden,
+                );
             }
 
             if style.frame == WindowFrame::NoTitle {
@@ -918,8 +926,12 @@ impl PlatformWindow {
 }
 
 struct WindowClass(*const Class);
+// Send is required when other dependencies apply the lazy_static feature 'spin_no_std'
+unsafe impl Send for WindowClass {}
 unsafe impl Sync for WindowClass {}
 struct WindowDelegateClass(*const Class);
+// Send is required when other dependencies apply the lazy_static feature 'spin_no_std'
+unsafe impl Send for WindowDelegateClass {}
 unsafe impl Sync for WindowDelegateClass {}
 
 lazy_static! {
@@ -1129,18 +1141,7 @@ extern "C" fn window_did_become_key(this: &Object, _: Sel, _: id) {
     });
 }
 
-extern "C" fn window_did_resign_key(this: &Object, _: Sel, _: id) {
-    with_state_delegate(this, |state, _delegate| {
-        if let Some(context) = state.context.get() {
-            context
-                .menu_manager
-                .borrow()
-                .borrow()
-                .get_platform_menu_manager()
-                .window_did_resign_active(state.platform_window.clone());
-        }
-    });
-}
+extern "C" fn window_did_resign_key(_this: &Object, _: Sel, _: id) {}
 
 extern "C" fn layout_if_needed(this: &mut Object, _sel: Sel) {
     unsafe {
