@@ -1,3 +1,4 @@
+pub mod app_delegate;
 pub mod binary_messenger;
 pub mod display;
 pub mod dpi;
@@ -9,8 +10,8 @@ pub mod dxgi_hook;
 pub mod engine;
 pub mod error;
 pub mod flutter_sys;
+pub mod hot_key;
 pub mod init;
-pub mod key_event;
 pub mod keyboard_map;
 pub mod menu;
 pub mod run_loop;
@@ -29,7 +30,7 @@ mod bindings {
 mod all_bindings {
     pub use super::bindings::Windows::Win32::{
         Foundation::*,
-        Graphics::{DirectDraw::*, Dwm::*, Gdi::*},
+        Graphics::{Dwm::*, Gdi::*},
         Storage::StructuredStorage::*,
         System::{
             Com::*, DataExchange::*, Diagnostics::Debug::*, LibraryLoader::*, Memory::*,
