@@ -28,7 +28,7 @@ pub fn get_raw_ptr<T>(t: &T) -> usize {
 ///
 /// ptr must point to a valid COM object instance
 pub unsafe fn com_object_from_ptr<T: Clone>(ptr: ::windows::RawPtr) -> Option<T> {
-    if ptr == std::ptr::null_mut() {
+    if ptr.is_null() {
         None
     } else {
         struct ComObject(windows::RawPtr);
@@ -74,6 +74,10 @@ impl BoolResultExt for BOOL {
     }
 }
 
+pub fn create_instance<T: Interface>(clsid: &Guid) -> Result<T> {
+    unsafe { CoCreateInstance(clsid, None, CLSCTX_ALL) }
+}
+
 pub(super) fn direct_composition_supported() -> bool {
     // for now dsiable direct composition until flutter composition problems
     // are resolved
