@@ -2,8 +2,10 @@ mod capsule;
 mod cell;
 mod diff;
 pub mod errno;
+mod future;
 mod log;
 
 pub use self::{diff::*, log::*};
 pub use capsule::*;
 pub use cell::*;
+pub use future::*;
